( cd usr/doc/totem-pl-parser-3.26.0 ; rm -rf html )
( cd usr/doc/totem-pl-parser-3.26.0 ; ln -sf ../../share/gtk-doc/html/totem-pl-parser html )
( cd usr/lib64 ; rm -rf libtotem-plparser-mini.so )
( cd usr/lib64 ; ln -sf libtotem-plparser-mini.so.18 libtotem-plparser-mini.so )
( cd usr/lib64 ; rm -rf libtotem-plparser-mini.so.18 )
( cd usr/lib64 ; ln -sf libtotem-plparser-mini.so.18.1.1 libtotem-plparser-mini.so.18 )
( cd usr/lib64 ; rm -rf libtotem-plparser.so )
( cd usr/lib64 ; ln -sf libtotem-plparser.so.18 libtotem-plparser.so )
( cd usr/lib64 ; rm -rf libtotem-plparser.so.18 )
( cd usr/lib64 ; ln -sf libtotem-plparser.so.18.1.1 libtotem-plparser.so.18 )
